/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.strategies.exploration;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import nu.xom.Element;
import nu.xom.Elements;
import nu.xom.ParsingException;
import nu.xom.ValidityException;

import org.apache.log4j.Logger;
import org.xml.sax.SAXException;

import de.unibi.airobots.bonsai.util.helper.annotation.MapArea;
import de.unibi.airobots.bonsai.util.helper.annotation.MapRegion;
import de.unibi.airobots.bonsai.util.xml.ParameterMissingException;
import de.unibi.airobots.bonsai.util.xml.XMLDecoderUtil;
import de.unibi.airobots.bonsai.util.xml.XMLEncoderUtil;

public class AnnotationMapBasedSearchStrategy extends
		ViewPointBasedSearchStrategy {

	private Logger logger = Logger.getLogger(this.getClass());

	private double minHeight;

	private double maxHeight;
 
	
	public AnnotationMapBasedSearchStrategy() {
	    
	}

	public AnnotationMapBasedSearchStrategy(double minHeight, double maxHeight) {
        this.minHeight = minHeight;
        this.maxHeight = maxHeight;
    }
	
	public void loadAnnotation(File annotationFile, MapArea.MapAreaType mapType) throws ValidityException, SAXException, ParsingException, IOException, NumberFormatException, ParameterMissingException {
		// TODO load Annotation file, extract points and add them to this class
		// by using superclass method addViewPoint()
		
		logger.debug("loadAnnotationFile " + annotationFile.getAbsolutePath());
		
		Element root = XMLDecoderUtil.loadXML(annotationFile.getAbsolutePath());
		
		Elements areas = root.getChildElements();
		
		logger.debug("interessting areas " + areas.toString());
		String op = "1";		
		for ( int i = 0; i < areas.size(); i++ ) {
			
			String type = areas.get(i).getAttributeValue(XMLEncoderUtil.TYPE_ATTRNAME);
			op += type + " " + mapType.name() + "\n";
			op += "1.5";
            if (type.equals(mapType.name())) {
            	MapArea area = XMLDecoderUtil.getMapArea(areas.get(i));
            	op += "2";
            	for (MapRegion r :area.getRegions()){
    				op += "3";
            	    if (r.getHeight() < minHeight || r.getHeight() > maxHeight){
            	        addMissMatchPoint(r.getPositionData());
            	        op += "mismatch: " + r.getLabel() + " " + r.getPositionData().getX() + " " + r.getPositionData().getY();
            	    } else {
            	        addViewPoint(r.getPositionData());   
            	        op += "match: " + r.getLabel() + " " + r.getPositionData().getX() + " " + r.getPositionData().getY();
            	    }
    			}
            }
			
		}
		
		FileOutputStream fos = new FileOutputStream("errorsop");
		fos.write(op.getBytes());
		fos.close();
	
	}	
	
}
