/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.xcf.sensors;

import java.io.IOException;

import net.sf.xcf.transport.Attachment;
import net.sf.xcf.transport.SerializeException;
import net.sf.xcf.transport.XOPData;

import org.apache.log4j.Logger;

import de.unibi.airobots.btl.data.BinarySlamMap;

/**
 * The SlamSensor receives the current SlamData provided by the robot.
 * 
 * @author sebschne
 * @author dklotz
 * @author jwienke
 */
public class XcfBinarySlamSensor extends
        XcfBtlPublisherSensor<BinarySlamMap> {

    private Logger logger = Logger.getLogger(getClass());

    /**
     * Constructor.
     * 
     * @param subscriberName
     *            name of the publisher providing the slam data
     */
    public XcfBinarySlamSensor(String subscriberName) {
        super(BinarySlamMap.class, subscriberName);
    }

    /**
     * Extract slam map attachment.
     * 
     * {@inheritDoc}
     */
    @Override
    protected void postProcessType(XOPData data, BinarySlamMap extractedType)
            throws IOException {

        try {
            Attachment mapPacket = data.getAttachment(extractedType.getUri());
            extractedType.setSlamMap(mapPacket.getAsFloatArray());
        } catch (SerializeException e) {
            logger.error("Error decoding slam map attachment.", e);
            throw new IOException(e);
        }

    }

}
